Legacy UAVCAN/CAN v0 in Python
==============================

***THIS PACKAGE HAS BEEN REPUBLISHED UNDER A DIFFERENT NAME: `pyuavcan_v0`***

**Please update your references to use [`pyuavcan_v0`](https://pypi.org/project/pyuavcan-v0/) -- a drop-in replacement.**

Find context at <https://github.com/UAVCAN/pyuavcan/issues/166>.

Ask questions at [forum.uavcan.org](https://forum.uavcan.org).
